#!/bin/bash
set -e
if [[ "${ENV}" != "localdev" ]]; then
    export AWS_DEFAULT_REGION=$(curl 169.254.169.254/latest/meta-data/placement/availability-zone/ | python3.8 -c "import json,sys;val=sys.stdin.read()[:-1];print(val);") || exit 1
    export REDIS_URL=auth.redis.cbd.internal
    export REDIS_URL_OLD=dashboard.redis.cbd.internal
fi

export worker_class="${worker_class:-"gevent"}" # Default worker class; either `gevent` or `sync`
export gunicorn_entrypoint="run"
export gunicorn_extra_args="-c /code/gunicorn_config.py"
worker_multiplier=3

if [[ "${worker_class}" == "gevent" ]]; then
    export gunicorn_entrypoint="gevent_entry"
    worker_multiplier=2
fi

# Set the number of workers; Recommended: 2*cpu_cores+1
if [[ -n "${cpu_resource}" ]]; then
    export workers=$(( ${worker_multiplier} * ((${cpu_resource} + 1000 / 2) / 1000) + 1))
else
    export workers=12
fi

if [[ -z "${LOG_LEVEL}" ]]; then
	LOG_LEVEL="DEBUG"
fi

echo "Using AWS_DEFAULT_REGION: ${AWS_DEFAULT_REGION}"
echo "LOG_LEVEL set to: ${LOG_LEVEL}"
echo "Worker class: ${worker_class}"
echo "Number of workers set to: ${workers}"

export OTEL_PYTHON_LOG_CORRELATION="true"
gunicorn -b 0.0.0.0:${PORT} --workers=${workers} --worker-class=${worker_class} --timeout=30 --log-level=${LOG_LEVEL} --chdir /code ${gunicorn_extra_args} ${gunicorn_entrypoint}:app
